@@ -215,7 +215,7 @@ bus_proxy_destroyed_cb (DBusGProxy  *bus_proxy,
         g_object_unref (*managerp);
         *managerp = NULL;
 
-        g_timeout_add (3000, (GSourceFunc)bus_reconnect, managerp);
+        g_timeout_add_seconds (3, (GSourceFunc)bus_reconnect, managerp);
 }
 
 static void
@@ -267,7 +267,11 @@ check_logdir (void)
 
         r = g_stat (log_path, &statbuf);
         if (r < 0 || ! S_ISDIR (statbuf.st_mode))  {
-                gdm_fail (_("Logdir %s does not exist or isn't a directory."), log_path);
+                if (g_mkdir (log_path, 0755) < 0) {
+                        gdm_fail (_("Logdir %s does not exist or isn't a directory."),
+                                  log_path);
+                }
+                g_chmod (log_path, S_IRWXU | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
         }
 }
 
@@ -495,6 +499,20 @@ signal_cb (int      signo,
         return ret;
 }
 
+static gboolean
+is_debug_set (void)
+{
+        gboolean debug = FALSE;
+
+        /* enable debugging for unstable builds */
+        if (gdm_is_version_unstable ()) {
+                return TRUE;
+        }
+
+        gdm_settings_direct_get_boolean (GDM_KEY_DEBUG, &debug);
+        return debug;
+}
+
 int
 main (int    argc,
       char **argv)
@@ -508,12 +526,10 @@ main (int    argc,
         gboolean            res;
         gboolean            xdmcp_enabled;
         GdmSignalHandler   *signal_handler;
-        static gboolean     debug            = FALSE;
         static gboolean     do_timed_exit    = FALSE;
         static gboolean     print_version    = FALSE;
         static gboolean     fatal_warnings   = FALSE;
         static GOptionEntry entries []   = {
-                { "debug", 0, 0, G_OPTION_ARG_NONE, &debug, N_("Enable debugging code"), NULL },
                 { "fatal-warnings", 0, 0, G_OPTION_ARG_NONE, &fatal_warnings, N_("Make all warnings fatal"), NULL },
                 { "timed-exit", 0, 0, G_OPTION_ARG_NONE, &do_timed_exit, N_("Exit after a time - for debugging"), NULL },
                 { "version", 0, 0, G_OPTION_ARG_NONE, &print_version, N_("Print GDM version"), NULL },
@@ -581,7 +597,7 @@ main (int    argc,
                 goto out;
         }
 
-        gdm_log_set_debug (debug);
+        gdm_log_set_debug (is_debug_set ());
 
         gdm_daemon_change_user (&gdm_uid, &gdm_gid);
         gdm_daemon_check_permissions (gdm_uid, gdm_gid);
@@ -592,7 +608,7 @@ main (int    argc,
         /* XDM compliant error message */
         if (getuid () != 0) {
                 /* make sure the pid file doesn't get wiped */
-                g_warning (_("Only root wants to run GDM"));
+                g_warning (_("Only the root user can run GDM"));
                 exit (-1);
         }
 
@@ -620,7 +636,9 @@ main (int    argc,
         main_loop = g_main_loop_new (NULL, FALSE);
 
         signal_handler = gdm_signal_handler_new ();
-        gdm_signal_handler_set_main_loop (signal_handler, main_loop);
+        gdm_signal_handler_set_fatal_func (signal_handler,
+                                           (GDestroyNotify)g_main_loop_quit,
+                                           main_loop);
         gdm_signal_handler_add_fatal (signal_handler);
         gdm_signal_handler_add (signal_handler, SIGTERM, signal_cb, NULL);
         gdm_signal_handler_add (signal_handler, SIGINT, signal_cb, NULL);
@@ -629,7 +647,7 @@ main (int    argc,
         gdm_signal_handler_add (signal_handler, SIGUSR1, signal_cb, NULL);
 
         if (do_timed_exit) {
-                g_timeout_add (1000 * 30, (GSourceFunc) timed_exit_cb, main_loop);
+                g_timeout_add_seconds (30, (GSourceFunc) timed_exit_cb, main_loop);
         }
 
         gdm_manager_start (manager);
