@@ -42,9 +42,12 @@
 
 #include "gdm-user-manager.h"
 #include "gdm-entry-menu-item.h"
+#include "gdm-settings-client.h"
 
 #define LOCKDOWN_DIR    "/desktop/gnome/lockdown"
-#define LOCKDOWN_KEY    LOCKDOWN_DIR "/disable_user_switching"
+#define LOCKDOWN_USER_SWITCHING_KEY LOCKDOWN_DIR "/disable_user_switching"
+#define LOCKDOWN_LOCK_SCREEN_KEY    LOCKDOWN_DIR "/disable_lock_screen"
+#define LOCKDOWN_COMMAND_LINE_KEY   LOCKDOWN_DIR "/disable_command_line"
 
 typedef enum {
         GSM_PRESENCE_STATUS_AVAILABLE = 0,
@@ -980,11 +983,11 @@ update_label (GdmAppletData *adata)
 
 #ifdef BUILD_PRESENSE_STUFF
         markup = g_strdup_printf ("<b>%s</b> <small>(%s)</small>",
-                                  gdm_user_get_real_name (GDM_USER (adata->user)),
+                                  gdm_user_get_display_name (GDM_USER (adata->user)),
                                   _(statuses[adata->current_status].display_name));
 #else
         markup = g_strdup_printf ("<b>%s</b>",
-                                  gdm_user_get_real_name (GDM_USER (adata->user)));
+                                  gdm_user_get_display_name (GDM_USER (adata->user)));
 #endif
         gtk_label_set_markup (GTK_LABEL (label), markup);
         g_free (markup);
@@ -1163,7 +1166,7 @@ create_sub_menu (GdmAppletData *adata)
                           G_CALLBACK (menuitem_style_set_cb), adata);
         g_signal_connect (adata->lock_screen_item, "activate",
                           G_CALLBACK (on_lock_screen_activate), adata);
-        gtk_widget_show (adata->lock_screen_item);
+        /* Only show if not locked down */
 
         adata->login_screen_item = gtk_image_menu_item_new_with_label (_("Switch User"));
         gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (adata->login_screen_item),
@@ -1229,12 +1232,18 @@ client_notify_lockdown_func (GConfClient   *client,
                 return;
         }
 
-        if (strcmp (key, LOCKDOWN_KEY) == 0) {
+        if (strcmp (key, LOCKDOWN_USER_SWITCHING_KEY) == 0) {
                 if (gconf_value_get_bool (value)) {
                         set_menu_visibility (adata, FALSE);
                 } else {
                         set_menu_visibility (adata, TRUE);
                 }
+        } else if (strcmp (key, LOCKDOWN_LOCK_SCREEN_KEY) == 0) {
+                if (gconf_value_get_bool (value)) {
+                        gtk_widget_hide (adata->lock_screen_item);
+                } else {
+                        gtk_widget_show (adata->lock_screen_item);
+                }
         }
 }
 
@@ -1416,6 +1425,11 @@ fill_applet (PanelApplet *applet)
         adata->applet = applet;
         adata->panel_size = 24;
 
+        if (! gdm_settings_client_init (GDMCONFDIR "/gdm.schemas", "/")) {
+                g_critical ("Unable to initialize settings client");
+                exit (1);
+        }
+
         adata->client = gconf_client_get_default ();
 
         gtk_widget_set_tooltip_text (GTK_WIDGET (applet), _("Change account settings and status"));
@@ -1430,7 +1444,7 @@ fill_applet (PanelApplet *applet)
 
         /* Hide the admin context menu items if locked down or no cmd-line */
         if (gconf_client_get_bool (adata->client,
-                                   "/desktop/gnome/lockdown/inhibit_command_line",
+                                   LOCKDOWN_COMMAND_LINE_KEY,
                                    NULL) ||
             panel_applet_get_locked_down (applet)) {
                 bonobo_ui_component_set_prop (popup_component,
@@ -1502,18 +1516,28 @@ fill_applet (PanelApplet *applet)
         adata->manager = gdm_user_manager_ref_default ();
         setup_current_user (adata);
 
+        gconf_client_add_dir (adata->client,
+                              LOCKDOWN_DIR,
+                              GCONF_CLIENT_PRELOAD_ONELEVEL,
+                              NULL);
+
         adata->client_notify_lockdown_id = gconf_client_notify_add (adata->client,
-                                                                    LOCKDOWN_KEY,
+                                                                    LOCKDOWN_DIR,
                                                                     (GConfClientNotifyFunc)client_notify_lockdown_func,
                                                                     adata,
                                                                     NULL,
                                                                     NULL);
 
-        if (gconf_client_get_bool (adata->client, LOCKDOWN_KEY, NULL)) {
+        if (gconf_client_get_bool (adata->client, LOCKDOWN_USER_SWITCHING_KEY, NULL)) {
                 set_menu_visibility (adata, FALSE);
         } else {
                 set_menu_visibility (adata, TRUE);
         }
+        if (gconf_client_get_bool (adata->client, LOCKDOWN_LOCK_SCREEN_KEY, NULL)) {
+                        gtk_widget_hide (adata->lock_screen_item);
+        } else {
+                        gtk_widget_show (adata->lock_screen_item);
+        }
 
         error = NULL;
         bus = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
